@@ -18,16 +18,20 @@
 # SOFTWARE.
 
 
-from oc_meta.lib.finder import ResourceFinder
-from oc_meta.lib.master_of_regex import comma_and_spaces, name_and_ids, one_or_more_spaces, semicolon_in_people_field
-from oc_meta.core.curator import get_edited_br_metaid
+import re
+from typing import List
+
 from oc_ocdm.graph import GraphSet
 from oc_ocdm.graph.entities.bibliographic import BibliographicResource
 from oc_ocdm.graph.entities.bibliographic_entity import BibliographicEntity
 from oc_ocdm.support import create_date
 from rdflib import URIRef
-from typing import List
-import re
+
+from oc_meta.core.curator import get_edited_br_metaid
+from oc_meta.lib.finder import ResourceFinder
+from oc_meta.lib.master_of_regex import (comma_and_spaces, name_and_ids,
+                                         one_or_more_spaces,
+                                         semicolon_in_people_field)
 
 
 class Creator(object):
@@ -211,7 +215,7 @@ class Creator(object):
                         venue_type = self.get_venue_type(self.type, venue_ids_list)
                     except UnboundLocalError:
                         error_message = f"[INFO:Creator] I found the venue {venue} for the resource of type {self.type}, but I don't know how to handle it"
-                        raise UnboundLocalError(msg=error_message)
+                        raise UnboundLocalError(error_message)
                     if venue_type:
                         venue_type = venue_type.replace(' ', '_')
                         getattr(self.venue_graph, f'create_{venue_type}')()
@@ -254,7 +258,7 @@ class Creator(object):
             self.issue_graph.is_part_of(self.venue_graph)
 
     @classmethod
-    def get_venue_type(cls, br_type:str, venue_ids:str) -> str:
+    def get_venue_type(cls, br_type:str, venue_ids:list) -> str:
         schemas = {venue_id.split(':')[0] for venue_id in venue_ids}
         if br_type in {'journal article', 'journal volume', 'journal issue'}:
             venue_type = 'journal'
