@@ -18,16 +18,18 @@
 # SOFTWARE.
 
 
-from filelock import FileLock
-from oc_meta.constants import CONTAINER_EDITOR_TYPES
-from oc_meta.lib.cleaner import Cleaner
-from oc_meta.lib.finder import *
-from oc_meta.lib.file_manager import *
-from oc_meta.lib.master_of_regex import *
-from typing import List, Tuple, Dict
 import json
 import os
 import re
+from typing import Dict, List, Tuple
+
+from filelock import FileLock
+
+from oc_meta.constants import CONTAINER_EDITOR_TYPES
+from oc_meta.lib.cleaner import Cleaner
+from oc_meta.lib.file_manager import *
+from oc_meta.lib.finder import *
+from oc_meta.lib.master_of_regex import *
 
 
 class Curator:
@@ -196,13 +198,16 @@ class Curator:
         :type row: Dict[str, str]
         :returns: None -- This method modifies the input CSV row without returning it.
         '''
+        br_type = row['type']
+        volume = row['volume']
+        issue = row['issue']
+        if br_type not in {'journal article', 'journal volume', 'journal issue'} and (volume or issue):
+            row['volume'] = ''
+            row['issue'] = ''
         Cleaner.clean_volume_and_issue(row=row)
         vol_meta = None
         br_id = row['id']
         venue = row['venue']
-        volume = row['volume']
-        issue = row['issue']
-        br_type = row['type']
         # Venue
         if venue:
             # The data must be invalidated, because the resource is journal but a volume or an issue have also been specified
@@ -440,26 +445,24 @@ class Curator:
         pattern = 'br/' if br else 'ra/'
         metaid = ''
         id_list = list(filter(None, id_list))
+        clean_list = list()
+        for elem in id_list:
+            if elem in clean_list:
+                continue
+            elem = Cleaner(elem).normalize_hyphens()
+            identifier = elem.split(':', 1)
+            schema = identifier[0].lower()
+            value = identifier[1]
+            if schema == 'meta':
+                metaid = value.replace(pattern, '')
+            else:
+                normalized_id = Cleaner(elem).normalize_id(valid_dois_cache=valid_dois_cache)
+                if normalized_id:
+                    clean_list.append(normalized_id)
         how_many_meta = [i for i in id_list if i.lower().startswith('meta')]
         if len(how_many_meta) > 1:
-            for pos, elem in enumerate(list(id_list)):
-                if 'meta' in elem.lower():
-                    id_list[pos] = ''
-        else:
-            for pos, elem in enumerate(list(id_list)):
-                elem = Cleaner(elem).normalize_hyphens()
-                identifier = elem.split(':', 1)
-                schema = identifier[0].lower()
-                value = identifier[1]
-                if schema == 'meta':
-                    if 'meta:' + pattern in elem.lower():
-                        metaid = value.replace(pattern, '')
-                    id_list[pos] = ''
-                else:
-                    normalized_id = Cleaner(elem).normalize_id(valid_dois_cache=valid_dois_cache)
-                    id_list[pos] = normalized_id
-        id_list = list(filter(None, id_list))
-        return id_list, metaid
+            clean_list = [i for i in clean_list if not i.lower().startswith('meta')]
+        return clean_list, metaid
 
     def conflict(self, idslist:List[str], name:str, id_dict:dict, col_name:str) -> str:
         if col_name == 'id' or col_name == 'venue':
@@ -510,11 +513,23 @@ class Curator:
             ras_list = list()
             for _, ra_id in sequence:
                 ra_name = self.rameta[ra_id]['title']
-                ra_ids = ' '.join(self.rameta[ra_id]['ids'])
-                ra = ra_name + ' [' + ra_ids + ']'
+                ra_ids = self.rameta[ra_id]['ids']
+                ra = self.build_name_ids_string(ra_name, ra_ids)
                 ras_list.append(ra)
             row[col_name] = '; '.join(ras_list)
 
+    @staticmethod
+    def build_name_ids_string(name, ids):
+        if name and ids:
+            ra_string = f"{name} [{' '.join(ids)}]"
+        elif name and not ids:
+            ra_string = name
+        elif ids and not name:
+            ra_string = f"[{' '.join(ids)}]"
+        elif not ids and not name:
+            ra_string = ''
+        return ra_string
+
     @staticmethod
     def __local_match(list_to_match, dict_to_match:dict):
         match_elem = dict()
@@ -683,7 +698,7 @@ class Curator:
                             venue_metaid = i
                 else:
                     venue_metaid = venue
-                row['venue'] = self.brmeta[venue_metaid]['title'] + ' [' + ' '.join(self.brmeta[venue_metaid]['ids']) + ']'
+                row['venue'] = self.build_name_ids_string(self.brmeta[venue_metaid]['title'], self.brmeta[venue_metaid]['ids'])
             br_key_for_editor = get_edited_br_metaid(row, metaid, venue_metaid)
             self.ra_update(row, metaid, 'author')
             self.ra_update(row, metaid, 'publisher')
