@@ -16,13 +16,14 @@
 
 
 from __future__ import annotations
-from oc_idmanager.issn import ISSNManager
-from oc_idmanager.orcid import ORCIDManager
+
+from oc_idmanager import DOIManager, ISSNManager, ORCIDManager
+
 from oc_meta.lib.csvmanager import CSVManager
-import unicodedata
+from oc_meta.plugins.ra_processor import RaProcessor
 
 
-class JalcProcessing:
+class JalcProcessing(RaProcessor):
     def __init__(self, orcid_index:str=None, doi_csv:str=None):
         self.doi_set = CSVManager.load_csv_column_as_set(doi_csv, 'id') if doi_csv else None
         orcid_index = orcid_index if orcid_index else None
@@ -31,7 +32,9 @@ class JalcProcessing:
         self._om = ORCIDManager()
 
     def csv_creator(self, item:dict) -> dict:
+        doi_manager = DOIManager(data=dict(), use_api_service=False)
         data = item['data']
+        doi = doi_manager.normalise(data['doi'], include_prefix=True)
         publisher = self.get_ja(data['publisher_list'])[0]['publisher_name'] if 'publisher_list' in data else ''
         title = self.get_ja(data['title_list'])[0]['title'] if 'title_list' in data else ''
         issue = data['issue'] if 'issue' in data else ''
@@ -45,27 +48,32 @@ class JalcProcessing:
             pages += first_page
             if last_page:
                 pages += f'-{last_page}'
-        return {
-            'title': unicodedata.normalize('NFKC', title),
-            'author': unicodedata.normalize('NFKC', '; '.join(self.get_authors(data))),
-            'issue': unicodedata.normalize('NFKC', issue),
-            'volume': unicodedata.normalize('NFKC', volume),
-            'venue': unicodedata.normalize('NFKC', self.get_venue(data)),
-            'pub_date': unicodedata.normalize('NFKC', self.get_pub_date(data)),
-            'pages': unicodedata.normalize('NFKC', pages),
-            'type': unicodedata.normalize('NFKC', self.get_type(data)),
-            'publisher': unicodedata.normalize('NFKC', publisher),
-            'editor': unicodedata.normalize('NFKC', '')
+        metadata = {
+            'id': doi,
+            'title': title,
+            'author': '; '.join(self.get_authors(data)),
+            'issue': issue,
+            'volume': volume,
+            'venue': self.get_venue(data),
+            'pub_date': self.get_pub_date(data),
+            'pages': pages,
+            'type': self.get_type(data),
+            'publisher': publisher,
+            'editor': ''
         }
-    
+        return self.normalise_unicode(metadata)
+        
     @classmethod
     def get_ja(cls, field:list) -> list:
         if all('lang' in item for item in field):
             ja = [item for item in field if item['lang'] == 'ja']
-            if not ja:
-                en = [item for item in field if item['lang'] == 'en']
+            ja = list(filter(lambda x: x['type'] != 'before' if 'type' in x else x, ja))
+            if ja:
+                return ja
+            en = [item for item in field if item['lang'] == 'en']
+            en = list(filter(lambda x: x['type'] != 'before' if 'type' in x else x, en))
+            if en:
                 return en
-            return ja
         return field
         
     def get_authors(self, data:dict) -> list:
@@ -84,21 +92,28 @@ class JalcProcessing:
                         full_name += f', {first_name}'
                 if full_name:
                     authors.append((sequence, full_name))
+                if 'researcher_id_list' in creator:
+                    print(data)
         return [author[1] for author in sorted(authors, key=lambda x: x[0])]
     
     def get_venue(self, data:dict) -> str:
+        venue_name = ''
         if 'journal_title_name_list' in data:
-            venue_name = [item for item in self.get_ja(data['journal_title_name_list']) if item['type'] == 'full'][0]['journal_title_name']
-        else:
-            venue_name = ''
+            candidate_venues = self.get_ja(data['journal_title_name_list'])
+            if candidate_venues:
+                full_venue = [item for item in candidate_venues if 'type' in item if item['type'] == 'full']
+                if full_venue:
+                    venue_name = full_venue[0]['journal_title_name']
+                elif candidate_venues:
+                    venue_name = candidate_venues[0]['journal_title_name']
         if 'journal_id_list' in data:
-            journal_ids = [journal_id['journal_id'] for journal_id in data['journal_id_list'] if journal_id['type'] in {'print', 'online'}]
+            journal_ids = {journal_id['journal_id'] for journal_id in data['journal_id_list'] 
+                if journal_id['type'] == 'ISSN'}
+        else:
+            journal_ids = list()
         venue_ids = list()
-        if journal_ids:
-            for journal_id in journal_ids:
-                issnid = self._issnm.normalise(journal_id, include_prefix=False)
-                if self._issnm.check_digit(issnid):
-                    venue_ids.append('issn:' + issnid)
+        for journal_id in journal_ids:
+            self.issn_worker(journal_id, venue_ids)
         return f"{venue_name} [{' '.join(venue_ids)}]" if venue_ids else venue_name
 
     @classmethod
@@ -129,4 +144,4 @@ class JalcProcessing:
                 day = pub_date_dict['publication_day'] if 'publication_day' in pub_date_dict else ''
                 if day:
                     pub_date_list.append(day)
-        return '-'.join(pub_date_list)
+        return '-'.join(pub_date_list)
\ No newline at end of file
