@@ -15,15 +15,16 @@
 # SOFTWARE.
 
 
-from oc_meta.lib.cleaner import Cleaner
-from oc_meta.lib.finder import *
-from oc_meta.lib.file_manager import *
-from oc_meta.lib.master_of_regex import *
-from oc_meta.core.curator import Curator
-from typing import List
 import json
 import os
 import re
+from typing import List
+
+from oc_meta.core.curator import Curator
+from oc_meta.lib.cleaner import Cleaner
+from oc_meta.lib.file_manager import *
+from oc_meta.lib.finder import *
+from oc_meta.lib.master_of_regex import *
 
 
 class RespAgentsCurator(Curator):
@@ -179,26 +180,24 @@ class RespAgentsCurator(Curator):
         pattern = 'ra/'
         metaid = ''
         id_list = list(filter(None, id_list))
+        clean_list = list()
+        for elem in id_list:
+            if elem in clean_list:
+                continue
+            elem = Cleaner(elem).normalize_hyphens()
+            identifier = elem.split(':', 1)
+            schema = identifier[0].lower()
+            value = identifier[1]
+            if schema == 'meta':
+                metaid = value.replace(pattern, '')
+            else:
+                normalized_id = Cleaner(elem).normalize_id(valid_dois_cache=dict())
+                if normalized_id:
+                    clean_list.append(normalized_id)
         how_many_meta = [i for i in id_list if i.lower().startswith('meta')]
         if len(how_many_meta) > 1:
-            for pos, elem in enumerate(list(id_list)):
-                if 'meta' in elem.lower():
-                    id_list[pos] = ''
-        else:
-            for pos, elem in enumerate(list(id_list)):
-                elem = Cleaner(elem).normalize_hyphens()
-                identifier = elem.split(':', 1)
-                schema = identifier[0].lower()
-                value = identifier[1]
-                if schema == 'meta':
-                    if 'meta:' + pattern in elem.lower():
-                        metaid = value.replace(pattern, '')
-                    id_list[pos] = ''
-                else:
-                    normalized_id = Cleaner(elem).normalize_id()
-                    id_list[pos] = normalized_id
-        id_list = list(filter(None, id_list))
-        return id_list, metaid
+            clean_list = [i for i in clean_list if not i.lower().startswith('meta')]
+        return clean_list, metaid
 
     def id_worker(self, col_name, name, idslist:List[str], publ_entity:bool):
         id_dict = self.idra
