@@ -2,7 +2,7 @@ from argparse import ArgumentParser
 from oc_meta.plugins.get_ids_from_citations import get_ids_from_citations
 
 
-if __name__ == '__main__':
+if __name__ == '__main__': # pragma: no cover
     arg_parser = ArgumentParser('run_preprocess.py', description='This script extracts the identifiers of the citing and cited documents from citation data organized in the CSV format accepted by OpenCitations. ')
     arg_parser.add_argument('-c', '--citations', dest='citations_dir', required=True,
                             help='The directory containing the citations files, either in CSV or ZIP format')
